@@ -4,7 +4,6 @@ from unitts.voice import Voice
 from pyobjus import autoclass, protocol
 from pyobjus.dylib_manager import load_framework, INCLUDE
 load_framework(INCLUDE.AVFoundation)
-load_framework('/System/Library/Frameworks/AppKit.framework')
 load_framework('/System/Library/Frameworks/Foundation.framework')
 NSTimer = autoclass('NSTimer')
 NSString = autoclass('NSString')
@@ -56,7 +55,6 @@ class IOSSpeechDriver(BaseDriver):
 	def __init__(self, proxy, **kw):
 		super().__init__(proxy)
 		self._tts = AVSpeechSynthesizer.alloc().init()
-		self._tts1 = AVSpeechSynthesizer()
 		# self._tts.delegate = self
 		self.rate = 200
 		self.volume = 1
@@ -65,7 +63,6 @@ class IOSSpeechDriver(BaseDriver):
 		self.set_stop_period()
 		self.voice = None
 		print(f'IOSTTS driver version {__version__}')
-		print('self._tts1=', dir(self._tts1))
 		self.speaking_sentence = None
 		self.get_voices()
 
@@ -147,7 +144,6 @@ class IOSSpeechDriver(BaseDriver):
 		utterance = AVSpeechUtterance.alloc().init(sentence.text)
 		self.set_utterances_by_sentence(utterance, sentence)
 		self._tts.speakUtterance_(utterance)
-		self._tts1.speak(utterance)
 		print('speak_sentence() finished')
 
 	def getProperty(self, name):
